capture log close

**** Please enter the directory containing your copy of the replication dataset between the quotes on the next line

local directory "C:\Users\saumitra\Dropbox\financeethnicconflict\israel_elections\stata\replication"
clear
cd "`directory'"

**** Install packages if needed: outreg2, ivreg2, reghdfe

********************************************************************************
* Table 1: Assignment to Treatment
********************************************************************************
set more off
use replicationdata.dta, clear
capture log close
log using "log/Table1.smcl", replace
*** This code generates the relevant cell values consolidated into Table 1
tab assettreat
tab isrstock
tab palstock
tab cash 
bysort late high: tab assettreat 
bysort late high: tab isrstock
bysort late high: tab palstock
bysort late high: tab cash
log close

********************************************************************************
* Table 2: Descriptive Statistics and Balance Tests
********************************************************************************

set more off
use replicationdata.dta, clear

local population="left_s3<."

mat balance=J(52,7,.)

local i=0
foreach var in right_2013 left_2013 p_index_s1 e_index_init tradestock6all male age ///
		postsecondary BA_student college_grad married r_sec  r_trad r_relig r_ultra ///
		g_jerusalem g_north g_haifa g_center g_telaviv g_south g_wb faminc willingrisk1to10 patient plitscore ///
		{

	sum `var' if `population' & assettreat==1
		mat balance[`i'*2+1,1]=round(r(mean) , 0.001)
		mat balance[`i'*2+2,1]=round(r(sd), 0.001)

	sum `var' if `population' & assettreat==0
		mat balance[`i'*2+1,2]=round(r(mean) , 0.001)
		mat balance[`i'*2+2,2]=round(r(sd), 0.001)

	reg `var' assettreat if `population' 
		mat balance[`i'*2+1,3]=round(_b[assettreat], 0.001)
		mat balance[`i'*2+2,3]=round(_se[assettreat], 0.001)
		test assettreat
		mat balance[`i'*2+1,4]=round(r(p), 0.0001)

	areg `var' assettreat if `population', absorb(block13) 
		mat balance[`i'*2+1,5]=round(_b[assettreat], 0.001)
		mat balance[`i'*2+2,5]=round(_se[assettreat], 0.001)
		test assettreat
		mat balance[`i'*2+1,6]=round(r(p), 0.0001)
		mat balance[`i'*2+1,7]=e(N)
		
	local ++i		
}


mat colnames balance=Mean_assettreat Mean_control OLS p FE p Obs
mat rownames balance=right_2013 x left_2013 x p_index_s1 x e_index_init x tradestock6all x male x age x ///
		postsecondary x BA_student x college_grad x married x r_sec x r_trad x r_relig x r_ultra x ///
		g_jerusalem x g_north x g_haifa x g_center x g_telaviv x g_south x g_wb x faminc x willingrisk1to10 x patient x plitscore x
			

capture log close
log using "log/Table2.smcl", replace
*** This code generates the relevant cell values consolidated into Table 2

mat li balance

log close

********************************************************************************	
* Table 3: Treatment Effects on Left and Right Vote in 2015
********************************************************************************
	
set more off
use replicationdata.dta, clear

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
/* omitted categories: relid is Secular, region (nafa) is Center (both are largest) */

local update="replace"

foreach depvar in left right { 

** RAW data: NO CONTROLS 
reg `depvar'_s3 assettreat, r
outreg2 using log/Table3 ,bdec(3) noaster label excel ctitle(`depvar', No Controls) nocons ///
	`update'

local update="append"
  
* control for demographics and strata 
areg `depvar'_s3  assettreat right_2013 left_2013 `dem_controls',  absorb (block13) r
outreg2 using log/Table3 ,bdec(3) noaster label excel ctitle(`depvar', Controls) nocons ///
	keep(assettreat right_2013 left_2013 tradestock6all r_trad r_relig ///
	r_ultra postsecondary BA_student college_grad willingrisk1to10 patient plitscore) ///
	`update'

* Re-weighted to represent jewish vote share in 2013   
areg `depvar'_s3  assettreat right_2013 left_2013 `dem_controls' [pw=vote_wgt],  absorb (block13)  r 
outreg2 using log/Table3 ,bdec(3) noaster label excel ctitle(`depvar', ReWeighted) nocons ///
	keep(assettreat right_2013 left_2013 tradestock6all r_trad r_relig ///
	r_ultra postsecondary BA_student college_grad willingrisk1to10 patient plitscore) ///
	`update'
	   
		   
* IV-TOT	
xi: ivreg2 `depvar'_s3    (asset_comp=assettreat) i.block13 right_2013 left_2013 `dem_controls', r first partial(i.block13)
outreg2 using log/Table3 ,bdec(3) noaster label excel ctitle(`depvar', TOT) nocons addstat(F(excluded instruments), `e(widstat)') ///
	keep(asset_comp right_2013 left_2013 tradestock6all r_trad r_relig ///
	r_ultra postsecondary BA_student college_grad willingrisk1to10 patient plitscore) ///
	sortvar(assettreat asset_comp right_2013 left_2013 tradestock6all r_trad r_relig ///
	r_ultra postsecondary BA_student college_grad willingrisk1to10 patient plitscore) ///
	`update'
	   
}


********************************************************************************
* Table 4: Effects of Election Day Stockholdings on Ordered Vote Choice
********************************************************************************

capture log close
set more off
use replicationdata.dta, clear

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
local controls="right_2013 left_2013 `dem_controls' "

local update="replace"

foreach depvar in coarseorder  { 
* baseline (assettreat ITT) 
areg `depvar'_s3 assettreat `controls', absorb (block13) r
	outreg2 using log/Table4, nocons keep(assettreat)  bdec(3) noaster label excel ///
	ctitle(`depvar', early) `update' 

local update="append"

* Divest before Election (assettreat ITT) 
areg `depvar'_s3 assettreat early `controls', absorb (block13) r
	outreg2 using log/Table4, nocons keep(assettreat early)  bdec(3) noaster label excel ///
	ctitle(`depvar', early) `update' 

* Voucher Treatment 
areg `depvar'_s3 assettreat cash `controls', absorb (block13) r
	outreg2 using log/Table4, nocons keep(assettreat cash)  bdec(3) noaster label excel ///
	ctitle(`depvar', cash) `update' 

local update="append"
	
* does having more skin in the game on election day have an additional effect, beyond the assettreat effect?
* use treatment and prices (both exogenous) to construct instument for stock holdings
	* use the stock value an individual would have had if they were a passive investor

** OLS for comparison 
areg `depvar'_s3 stockval_mar16 assettreat `controls', absorb(block13) r /* partial(i.block13) */
outreg2 using log/Table4 , nocons keep(stockval_mar16 assettreat) bdec(3) noaster label excel /* addstat(F(excluded instruments), `e(widstat)')*/  ///
	sortvar(assettreat early high cash ) /// 
	ctitle(`depvar', OLS) `update'

** Now the IV.
xi: ivreg2 `depvar'_s3  (stockval_mar16=stockval_itt) assettreat `controls' i.block13, r /* partial(i.block13) */
outreg2 using log/Table4, nocons keep(stockval_mar16 assettreat) bdec(3) noaster label excel /* addstat(F(excluded instruments), `e(widstat)')*/  ///
	sortvar(assettreat early high cash ) /// 
	ctitle(`depvar', IV) `update'

	}
	



********************************************************************************
* Table 5: Treatment Effects on Attitudes 
********************************************************************************

set more off
use replicationdata.dta, clear

* we use peace and economic attitudes indices using Kling et al. 2007


local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 

local update="replace"


foreach depvar in p_index_s3 e_index_jul15   {	

*OLS  
areg `depvar' assettreat right_2013 left_2013 `dem_controls',  absorb (block13) r
outreg2 using log/Table5 , nocons keep(assettreat)  bdec(3) noaster label excel ///
	ctitle(`depvar', All) `update' sideway  nor2 

local update="append"

areg `depvar' assettreat right_2013 left_2013 `dem_controls' if tradestock6all==0,  absorb (block13) r
outreg2 using log/Table5 , nocons keep(assettreat)  bdec(3) noaster label excel ///
	ctitle(`depvar', Inexperienced) `update' sideway  nor2 
}

* specific outcomes (oprobits - ITT only. OLS/IV-TOT results qualitatively similar)

foreach depvar in pdealtwostate_s3 pdeal1967_s3 pdealsplitjerus_s3 pdealpalrefcomp_s3 ///
		e_equal_jul15 e_privat_jul15 e_poor_jul15 e_ktax_jul15 ///
	 {  

*OPROBIT - ITT 
xi: oprobit `depvar' assettreat right_2013 left_2013 `dem_controls' i.block13,  r
outreg2 using log/Table5 , nocons keep(assettreat)  bdec(3) noaster label excel ///
	ctitle(`depvar', All) /*addstat(Pseudo R-squared, `e(r2_p)') */ `update' sideway  

xi: oprobit `depvar' assettreat right_2013 left_2013 `dem_controls' i.block13 if tradestock6all==0,  r
outreg2 using log/Table5 , nocons keep(assettreat)  bdec(3) noaster label excel ///
	ctitle(`depvar', Inexperienced)/* addstat(Pseudo R-squared, `e(r2_p)') */ `update' sideway  
}


*descriptives
sum p_index_s3 e_index_jul15 pdealtwostate_s3 pdeal1967_s3 pdealsplitjerus_s3 pdealpalrefcomp_s3 ///
		e_equal_jul15 e_privat_jul15 e_poor_jul15 e_ktax_jul15


********************************************************************************
* Table 6: Salience, Media and the Economic Consequences of the Peace
********************************************************************************
*** This code generates the relevant cell values consolidated into Table 6

** Panel A. What is the most important issue in Israel today?
set more off
use replicationdata.dta, clear


local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
local controls="i.block13 right_2013 left_2013 `dem_controls'"

local update="replace"


foreach depvar in mainissueecon_s3 mainissuepolsec_s3 {

reg `depvar' assettreat `controls',  r
	outreg2 using log/Table6 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`depvar', All)  ///
		sideway /* noobs nor2 */  `update' 
	
	local update="append"
	
		reg `depvar' assettreat `controls' if tradestock6all==0, r
	outreg2 using log/Table6 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`depvar', Inexperienced)  ///
		sideway /* noobs nor2 */  `update' 
					
		}


* B. Economic and Political Facts
*****************

foreach depvar in pol_info_score econ_info_score c_mkt_up_percent  {
	reg `depvar'  assettreat `controls', r
	outreg2 using log/Table6 , nocons keep(assettreat)  bdec(3) noaster label excel  ///
		ctitle(`depvar', All) ///
		sideway /* noobs nor2 */  `update' 

	reg `depvar' assettreat `controls' if tradestock6all==0, r
	outreg2 using log/Table6 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`depvar', Did Not Trade) ///
		sideway /* noobs nor2 */  `update' 
}


** C: Media Consumption
set more off
use replicationdata.dta, clear

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
local controls="i.block13 right_2013 left_2013 `dem_controls'"

foreach depvar in news_fin_sum news_marker news_globe news_kalkalist news_nonfin_sum news_haaretz  news_isrhayom ///
	   {
	reg `depvar'  assettreat `controls', r
	outreg2 using log/Table6 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`depvar', All)  ///
		sideway   `update' 

	local update="append"
		
	reg `depvar' assettreat `controls' if tradestock6all==0, r
	outreg2 using log/Table6 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`depvar', Did Not Trade)  ///
		sideway  `update' 
}



**** D: Consequences of a Two-State Agreement
set more off

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
local controls="i.block13 right_2013 left_2013 `dem_controls'"


* sociotropic and egotistic indices

foreach depvar in twost_isr_index_s3 twost_per_index_s3 {

reg `depvar' assettreat `controls',  r
	outreg2 using log/Table6 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`depvar', All)  ///
		sideway   `update' 
	
	local update="append"
	
		reg `depvar' assettreat `controls' if tradestock6all==0, r
	outreg2 using log/Table6 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`depvar', Inexperienced)  ///
		sideway   `update' 
					
		}

* specific outcomes	
foreach depvar in rtwostisreconomicaf_s3 rtwostisrsecurityaf_s3 rtwostperseconomicaf_s3 rtwostperssafetyaf_s3   {

	*tab `depvar'	
	
	oprobit `depvar'  assettreat `controls', r
	outreg2 using log/Table6 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`depvar', All)  ///
		sideway   `update' 

	local update="append"
		
	oprobit `depvar' assettreat `controls' if tradestock6all==0, r
	outreg2 using log/Table6 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`depvar', Inexperienced)  ///
		sideway   `update' 
}




* descriptives
sum mainissueecon_s3 mainissuepolsec_s3   pol_info_score econ_info_score c_mkt_up_percent ///
news_fin_sum news_marker news_globe news_kalkalist news_nonfin_sum news_haaretz  news_isrhayom ///
	  twost_isr_index_s3 twost_per_index_s3 rtwostisreconomicaf_s3 rtwostisrsecurityaf_s3 rtwostperseconomicaf_s3 rtwostperssafetyaf_s3   




********************************************************************************
* Table 7: Differential Effects by Risk Aversion
********************************************************************************

set more off
use replicationdata.dta, clear

gen averse = willingrisk1to10<=5  // median and below
label var averse "Risk Averse
gen asset_averse= assettreat*averse
label var asset_averse "Asset Treatment * Risk Averse"

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses patient  litscore " 
local controls="i.block13 right_2013 left_2013 `dem_controls'"
* note the dem controls now don't include willingrisk1to10 since we control for the dummy for risk averse 

local update="replace"

foreach depvar in coarseorder_s3 p_index_s3 e_index_jul15 twost_isr_index_s3 twost_per_index_s3 /* pdealtwostate pdeal1967 pdealsplitjerus pdealpalrefcomp pdealtwostate_yn pdeal1967_yn pdealsplitjerus_yn pdealpalrefcomp_yn*/ ///
	 { 

* full regression from table 2  with added interaction
reg `depvar'  assettreat averse asset_averse `controls', r
outreg2 using log/Table7 , nocons keep(assettreat averse asset_averse) noaster bdec(3) label excel ///
	ctitle(`depvar')  `update'

	local update="append"
	}



********************************************************************************
* Table 8: Voting Intentions, One Year Post-Intervention
********************************************************************************

*OLS and IV, all regressions include full set of strata and demogs

set more off
use replicationdata.dta, clear

label var left_s3 "Voted Left '15"
label var right_s3 "Voted Right '15"

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
/* omitted relid is Secular, omitted nafa is Center (both largest) */

local update="replace"

foreach depvar in coarseorder { 
  
* OLS  
areg `depvar'_2016  assettreat right_2013 left_2013 `dem_controls',  absorb (block13) r
outreg2 using log/Table8 ,bdec(3) noaster label excel ctitle(`depvar', ITT) nocons  ///
	keep(assettreat ) ///
	`update'

local update="append"

* IV-TOT	
xi: ivreg2 `depvar'_2016    (asset_comp=assettreat) i.block13 right_2013 left_2013 `dem_controls', r
outreg2 using log/Table8 ,bdec(3) noaster label excel ctitle(`depvar', TOT) nocons addstat(F(excluded instruments), `e(widstat)') ///
	keep(asset_comp ) ///
	`update'

	
* Control for vote in 2015

*OLS
areg `depvar'_2016  assettreat right_2013 left_2013 right_s3 left_s3 `dem_controls',  absorb (block13) r
outreg2 using log/Table8 ,bdec(3) noaster label excel ctitle(`depvar', ITT) nocons ///
	keep(assettreat  right_s3 left_s3) ///
	`update'


* IV-TOT - controlling for vote in 2015 	
xi: ivreg2 `depvar'_2016    (asset_comp=assettreat) i.block13 right_2013 left_2013 right_s3 left_s3 `dem_controls', r
outreg2 using log/Table8 ,bdec(3) noaster label excel ctitle(`depvar', TOT) nocons addstat(F(excluded instruments), `e(widstat)') ///
	keep(asset_comp  right_s3 left_s3) ///
	sortvar(assettreat asset_comp  right_s3 left_s3) ///
	`update'
}



********************************************************************************
* Table 9: Effects of In-Group vs Out-Group Financial Assets
********************************************************************************

* all regs control for demogs, strata and past vote. 
set more off
use replicationdata.dta, clear
replace pricechange_m16 = pricechange_m16 / 100
label var pricechange_m16 "Price change of asset by elections (bp)"


replace pchangem16_comp = pchangem16_comp / 100
label var pchangem16_comp "Price change of asset by elections (bp)"

gen isrcash=(isrstock==1 | cash==1)

gen isrcash_comp = palstock==0 & asset_comp==1
label var isrcash "Non-Palestinian Assets"
label var isrcash_comp  "Non-Palestinian Assets"
label var palstock "Palestinian Assets"


local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
/* omitted relid is Secular, omitted nafa is Center (both largest) */

local update="replace"
foreach depvar in coarseorder p_index {   
	
*palstock
areg `depvar'_s3  palstock isrcash right_2013 left_2013 `dem_controls',  absorb (block13) r
outreg2 using log/Table9 ,bdec(3) noaster label excel ctitle(`depvar', pal) nocons ///
	keep( palstock isrcash) ///
	`update'

local update="append"	

	* TOT
	
xi:	ivreg2 `depvar'_s3  (pal_comp isrcash_comp = palstock isrcash)  right_2013 left_2013 `dem_controls' i.block13,  r
outreg2 using log/Table9 ,bdec(3) noaster label excel ctitle(`depvar', TOT) nocons addstat(F(excluded instruments), `e(widstat)') ///
	keep( pal_comp isrcash_comp) ///
	`update'

	areg `depvar'_s3  assettreat pricechange_m16 right_2013 left_2013 `dem_controls',  absorb (block13) r
outreg2 using log/Table9 ,bdec(3) noaster label excel ctitle(`depvar', pal) nocons ///
	keep(assettreat pricechange_m16 ) ///
	`update'
	
local update="append"	
xi:	ivreg2 `depvar'_s3  (asset_comp pchangem16_comp = assettreat pricechange_m16) right_2013 left_2013 `dem_controls' i.block13, r
outreg2 using log/Table9 ,bdec(3) noaster label excel ctitle(`depvar', TOT) nocons addstat(F(excluded instruments), `e(widstat)') ///
	keep(asset_comp pchangem16_comp) ///
	`update'
	
*price change
areg `depvar'_s3  palstock isrcash pricechange_m16 right_2013 left_2013 `dem_controls',  absorb (block13) r
outreg2 using log/Table9 ,bdec(3) noaster label excel ctitle(`depvar', prices) nocons ///
	keep(palstock isrcash pricechange_m16) sortvar(assettreat palstock isrcash pricechange_m16) ///
	`update'


xi:	ivreg2 `depvar'_s3  (pal_comp isrcash_comp pchangem16_comp= palstock isrcash pricechange_m16)  right_2013 left_2013 `dem_controls' i.block13,  r
outreg2 using log/Table9 ,bdec(3) noaster label excel ctitle(`depvar', TOT) nocons addstat(F(excluded instruments), `e(widstat)') ///
	keep( pal_comp isrcash_comp pchangem16_comp) sortvar(assettreat asset_comp palstock pal_comp isrcash isrcash_comp pricechange_m16 pchangem16_comp) ///
	`update'
}





********************************************************************************
* Table A1: Comparison of the Sample and the Israeli Population
********************************************************************************

set more off
use replicationdata.dta, clear

* gen vars for the comparison
gen female=1-male

gen age18_24= (age>=18 & age<=24)
gen age25_34= (age>=25 & age<=34)
gen age35_44= (age>=35 & age<=44)
gen age45_54= (age>=45 & age<=54)
gen age55_64= (age>=55 & age<=64)
gen age65_= (age>=65 & age<.)

foreach var in age18_24 age25_34 age35_44 age45_54 age55_64 age65_ {
 gen m_`var'=`var' if male
 gen f_`var'=`var' if female
}

*religiosity categories are only reported for age>=20 
foreach var in r_sec r_trad r_relig r_ultra {
	gen `var'_20=`var' if age>=20
}


// education categories
gen e_less_hi = newedu==0
gen e_highschool = newedu==1
gen e_post_ba = newedu==2 | newedu==3
gen e_college = newedu==4

gen income =faminc/100	// later multiply by 100

* comparison table
local varlist="g_jerusalem g_north g_haifa g_center g_telaviv g_south g_wb female  m_age18_24 m_age25_34 m_age35_44 m_age45_54 m_age55_64 m_age65_ f_age18_24 f_age25_34 f_age35_44 f_age45_54 f_age55_64 f_age65_  r_sec_20 r_trad_20 r_relig_20 r_ultra_20 e_less_hi e_highschool e_post_ba e_college income"

local popall="assettreat<."	//all
local popvote="left_s3<."

mat stats=J(32,2,.)

local i=1
foreach var in `varlist' {
	sum `var' if `popall'
	mat stats[`i',1]=100*round(r(mean) , 0.001) 

	sum `var' if `popvote' 
	mat stats[`i',2]=100*round(r(mean) , 0.001)

	local ++i		
}
	sum income if `popall' ,d
	mat stats[`i',1]=100*round(r(p50) , 0.001)

	sum income if `popvote' ,d
	mat stats[`i',2]=100*round(r(p50) , 0.001)

mat colnames stats= ALL vote_observed
mat rownames stats= `varlist' median_inc
			

capture log close
log using "log/TableA1.smcl", replace
*** This code generates the relevant columns summarizing the sample in Table A1.
*** These were then augmented with additional columns from the Statistical Abstract of Israel (see notes)

mat li stats

log close




********************************************************************************
* Table A2: Balance by Sub-Treatment
********************************************************************************


set more off
use replicationdata.dta, clear

local population="left_s3<."

mat balance=J(52,11,.)

local i=0
foreach var in right_2013 left_2013 p_index_s1 e_index_init tradestock6all male age ///
		postsecondary BA_student college_grad married r_sec  r_trad r_relig r_ultra ///
		g_jerusalem g_north g_haifa g_center g_telaviv g_south g_wb faminc willingrisk1to10 patient plitscore ///
		{

	sum `var' if `population' & assettreat==0	// mean in control
		mat balance[`i'*2+1,1]=round(r(mean) , 0.001)
		mat balance[`i'*2+2,1]=round(r(sd), 0.001)

	reg `var' assettreat if `population' & (assettreat==0 | late==1), 	// compare late to control
		mat balance[`i'*2+1,2]=round(_b[assettreat], 0.001)
		mat balance[`i'*2+2,2]=round(_se[assettreat], 0.001)
		test assettreat
		mat balance[`i'*2+1,3]=round(r(p), 0.0001)

	reg `var' assettreat if `population' & (assettreat==0 | cash==1), 	// compare cash to control
		mat balance[`i'*2+1,4]=round(_b[assettreat], 0.001)
		mat balance[`i'*2+2,4]=round(_se[assettreat], 0.001)
		test assettreat
		mat balance[`i'*2+1,5]=round(r(p), 0.0001)

	reg `var' assettreat if `population' & (assettreat==0 | high==1), 	// compare high to control
		mat balance[`i'*2+1,6]=round(_b[assettreat], 0.001)
		mat balance[`i'*2+2,6]=round(_se[assettreat], 0.001)
		test assettreat
		mat balance[`i'*2+1,7]=round(r(p), 0.0001)

	reg `var' assettreat if `population' & (assettreat==0 | palstock==1), 	// compare palstock to control
		mat balance[`i'*2+1,8]=round(_b[assettreat], 0.001)
		mat balance[`i'*2+2,8]=round(_se[assettreat], 0.001)
		test assettreat
		mat balance[`i'*2+1,9]=round(r(p), 0.0001)

	reg `var' assettreat if `population' & (assettreat==0 | isrstock==1), 	// compare isrstock to control
		mat balance[`i'*2+1,10]=round(_b[assettreat], 0.001)
		mat balance[`i'*2+2,10]=round(_se[assettreat], 0.001)
		test assettreat
		mat balance[`i'*2+1,11]=round(r(p), 0.0001)
		
	local ++i		
}


mat colnames balance=Control_mean late p cash p high p pal p isr p
mat rownames balance=right_2013 x left_2013 x p_index_s1 x e_index_init x tradestock6all x male x age x ///
		postsecondary x BA_student x college_grad x married x r_sec x r_trad x r_relig x r_ultra x ///
		g_jerusalem x g_north x g_haifa x g_center x g_telaviv x g_south x g_wb x faminc x willingrisk1to10 x patient x plitscore x
			

capture log close
log using "log/TableA2.smcl", replace
*** This code generates the relevant cell values consolidated into Table A2

mat li balance

log close


********************************************************************************
* Table A3: Balance Across Sub-Treatments
********************************************************************************

set more off
use replicationdata.dta, clear

local varlist="right_2013 left_2013 p_index_s1 e_index_init tradestock6all male age postsecondary BA_student college_grad married r_sec  r_trad r_relig r_ultra	g_jerusalem g_north g_haifa g_center g_telaviv g_south g_wb faminc willingrisk1to10 patient plitscore"

mat fbalance=J(18,4,.)
local i=0	//treatments

foreach subtreat in assettreat late high cash palstock isrstock {

	local pop_control="left_s3<. & (assettreat==0 | `subtreat'==1)"	//comparing subtreatment to control
	local pop_treated="left_s3<. & assettreat==1"			//comparing subtreatment to other subtreatments within assettreat

	local comp_control="left_s3<. & (assettreat==0 | (`subtreat'==1 & stat_instructions==1))"	//comparing subtreatment compliers to control
	local comp_treated="left_s3<. & assettreat==1 & stat_instructions==1"			//comparing subtreatment to other subtreatments within assettreat compliers

	local j=1 // population
	foreach population in "`pop_control'" "`pop_treated'"  "`comp_control'"  "`comp_treated'"  {
		reg `subtreat' `varlist' if `population'
		testparm*
		mat fbalance[3*`i'+1,`j']=round(e(F) , 0.01)
		mat fbalance[3*`i'+2,`j']=round(r(p) , 0.001)
		mat fbalance[3*`i'+3,`j']=e(N)
	
		dis "******"
		dis "`subtreat'" 
		dis "`j'" "population=" "`population'"
		dis "F=" e(F)
		dis "p_value=" r(p)
		dis "******"
		local ++j		
	}
local ++i		

}

mat colnames fbalance=Control other_subtreatments
mat rownames fbalance=assettreat p N late p N high p N cash p N palstock p N isrstock p N 


capture log close
log using "log/TableA3.smcl", replace
*** This code generates the relevant cell values consolidated into Table A3

mat li fbalance

log close


********************************************************************************
* Table A4: Attrition
********************************************************************************
capture log close

set more off
use replicationdata.dta, clear


log using "log/TableA4.smcl", replace
*** This code generates the relevant cell values consolidated into Table A4 as well as tests for selective attrition 
*** referenced in the text.

foreach var in assettreat coarseorder_s3 p_index_s3 e_index_jul15 coarseorder_2016 {
	tab assettreat if `var'<.
}


* report tests for selective attrition in our main outcome vars (voting in 2015)
*****************************************************************************************************
set more off
use replicationdata.dta, clear

* we have data on the main outcome for 97.3% of subjects, so very little attrition. 
* moreover nonattrition rates are similar across treatment and control (97.4%) vs. (97.3%) 
*prtest vote_observed, by(assettreat)

gen vote_observed=(left_s3<.)

table assettreat, c(count left_2013 sum vote_observed mean vote_observed)
prtest vote_observed, by(assettreat)

foreach var in left_s3 p_index_s3 e_index_jul15 left_2016 {
gen `var'_observed=(`var'<.)
table assettreat, c(count left_2013 sum `var'_observed mean `var'_observed)
prtest `var'_observed, by(assettreat)
}

log close

********************************************************************************
* Table A5: Effects of Paper vs Realized Loss
********************************************************************************
capture log close
set more off
use replicationdata.dta, clear

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
local controls="right_2013 left_2013 `dem_controls' "

local update="replace"

foreach depvar in coarseorder  { 
* baseline (assettreat ITT) 
areg `depvar'_s3 assettreat `controls', absorb (block13) r
	outreg2 using log/TableA5 , nocons keep(assettreat)  bdec(3) noaster label excel ///
	ctitle(`depvar', early) `update' 

local update="append"

* Early Divest (assettreat ITT) 
areg `depvar'_s3 assettreat early `controls', absorb (block13) r
	outreg2 using log/TableA5 , nocons keep(assettreat early)  bdec(3) noaster label excel ///
	ctitle(`depvar', early) `update' 

* Voucher Treatment
areg `depvar'_s3 assettreat cash `controls', absorb (block13) r
	outreg2 using log/TableA5 , nocons keep(assettreat cash)  bdec(3) noaster label excel ///
	ctitle(`depvar', cash) `update' 

local update="append"
	
* does having more skin on election day have an additional effect, beyond the assettreat effect?
* use treatment and prices (both exogenous) to construct instument for stock holdings


xi: areg `depvar'_s3 early_winner early_loser late_winner late_loser cash  `controls' , absorb(block13) r
	outreg2 using log/TableA5 , nocons keep(assettreat early_winner early_loser late_winner late_loser cash)  bdec(3) noaster label excel ///
     sortvar(assettreat cash early_winner early_loser late_winner late_loser) ///
	 ctitle(`depvar', loss vs gains) `update'
	 
 xi: ivreg2 `depvar'_s3 (early_portgain early_portloser late_portgain late_portloser = early_winner early_loser late_winner late_loser)  cash  `controls' i.block13,  r   partial(i.block13)
	outreg2 using log/TableA5 , nocons keep(assettreat early_portgain early_portloser late_portgain late_portloser cash)  bdec(3) noaster label excel  /// % Note that early_portloser and late_portloser are perfectly collinear so do not report F-stat on excluded.
	   sortvar(assettreat early cash  stockval_mar16 early_winner early_loser late_winner late_loser early_portgain early_portloser late_portgain late_portloser ) ///
	   	 ctitle(`depvar', IV) `update'
		 
***** For the Risk Averse ***** 
xi: areg `depvar'_s3 early_winner early_loser late_winner late_loser cash  `controls' if willingrisk1to10<=5 , absorb(block13) r
	outreg2 using log/TableA5 , nocons keep(assettreat early_winner early_loser late_winner late_loser cash)  bdec(3) noaster label excel ///
     sortvar(assettreat cash early_winner early_loser late_winner late_loser) ///
	 ctitle(`depvar', risk averse) `update'
	 
 xi: ivreg2 `depvar'_s3 (early_portgain early_portloser late_portgain late_portloser = early_winner early_loser late_winner late_loser)  cash  `controls' i.block13 if willingrisk1to10<=5,  r  partial(i.block13) 
	outreg2 using log/TableA5, nocons keep(assettreat early_portgain early_portloser late_portgain late_portloser cash)  bdec(3) noaster label excel  /// % Note that early_portloser and late_portloser are perfectly collinear so do not report F-stat on excluded.
	   sortvar(assettreat early cash  stockval_mar16 early_winner early_loser late_winner late_loser early_portgain early_portloser late_portgain late_portloser ) ///
	   	 ctitle(`depvar', IV) `update'
		 
		 local update="replace"
	}
	


********************************************************************************
* Table A6: Wealth Effects
********************************************************************************

set more off
use replicationdata.dta, clear

*note we drop i.newses from the controls and include poor in the "poor" specs

gen asset_poor=assettreat*poor
label var asset_poor "Asset Treatment * Below Avg Income"
label var poor "Below Avg Income"	
local update="replace"


foreach depvar in coarseorder_s3 p_index_s3 e_index_jul15 {
* assettreat interacted with poor : 

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb willingrisk1to10 poor patient plitscore " 
local controls="i.block13 right_2013 left_2013 `dem_controls'"
reg `depvar'  assettreat poor asset_poor `controls', r
outreg2 using log/TableA6 , nocons keep(assettreat poor asset_poor)  bdec(3) label excel noaster ///
	ctitle(`depvar', Income) `update' 

local update="append"

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb willingrisk1to10 i.newses patient plitscore " 
local controls="i.block13 right_2013 left_2013 `dem_controls'"

* assettreat by high: 
reg `depvar'  assettreat high `controls', r
outreg2 using log/TableA6 , nocons keep(assettreat poor high)  bdec(3) label excel noaster ///
	ctitle(`depvar', Asset Treatment) `update' 

	}	 


********************************************************************************
* Table A7: Subjective Well-Being and Affect
********************************************************************************

set more off
use replicationdata.dta, clear

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
local controls="i.block13 right_2013 left_2013 `dem_controls'"

** these are all ordinal vars, so report oprobits, but the result is the same with OLS: none is significant!
*gen lifesat_s3=5-overlifesatisf_s3 // reverse scale: 1=not at all satisfied, 4=very satisfied

local update="replace"

* index
reg swb_index_s3  assettreat `controls', r
outreg2 using log/TableA7 , nocons keep(assettreat)  bdec(3) noaster label excel ///
	ctitle(`depvar', All)  ///
	sideway /* noobs nor2 */  `update' 

local update="append"

reg swb_index_s3  assettreat `controls' if tradestock6all==0, r
outreg2 using log/TableA7 , nocons keep(assettreat)  bdec(3) noaster label excel ///
	ctitle(`depvar', Inexperienced)  ///
	sideway /* noobs nor2 */  `update' 


foreach depvar in  lifesat_s3 rtgeneralwellbeing_s3 rtfamilyhappiness_s3 rthealth_s3 rtmoral_s3 ///
	rtfamilyrelation_s3 rtfinsecurity_s3 rtgensecurity_s3 rtnumchoices_s3 rtsiglife_s3 {

	*tab `depvar'	
	
	oprobit `depvar'  assettreat `controls', r
	outreg2 using log/TableA7 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`depvar', All)  ///
		sideway /* noobs nor2 */  `update' 

		
	oprobit `depvar' assettreat `controls' if tradestock6all==0, r
	outreg2 using log/TableA7 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`depvar', Inexperienced)  ///
		sideway /* noobs nor2 */  `update' 
}



* descriptives
sum swb_index_s3 lifesat_s3 rtgeneralwellbeing_s3 rtfamilyhappiness_s3 rthealth_s3 rtmoral_s3 ///
	rtfamilyrelation_s3 rtfinsecurity_s3 rtgensecurity_s3 rtnumchoices_s3 rtsiglife_s3

	
********************************************************************************
* Table B1: Vote Transition Matrices in Treatment and Control, 2013 - 2015
********************************************************************************
capture log close
set more off
use replicationdata.dta, clear

log using "log/TableB1.smcl", replace
*** This code generates the relevant cell values consolidated into Table B1 


byso assettreat: tab coarseorder_2013 coarseorder_s3, row

log close


********************************************************************************
* Table B2 : Treatment Effects on Left and Right Vote in 2015  
********************************************************************************

use replicationdata.dta, clear

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb willingrisk1to10 poor patient plitscore " 
local controls="i.block13 right_2013 left_2013 `dem_controls'"

tab party_s3, nol

local update="replace"

su v_uarabp v_meretz v_zu v_yeshatid v_kulanu v_shas v_yahaduthatorah v_likud v_yisraelbeitenu  v_haamitanu v_habayit v_other v_didnotvote if left_s3~=.

foreach party in v_uarabp v_meretz v_zu v_yeshatid v_kulanu v_shas v_yahaduthatorah v_likud v_yisraelbeitenu  v_haamitanu v_habayit v_other v_didnotvote {

reg `party' assettreat  if left_s3~=.,  robust
outreg2 using log/TableB2 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`party',  no controls)   `update' ///
		
reg `party' assettreat `controls' if left_s3~=.,  robust

local update="append"

outreg2 using log/TableB2 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`party', ITT)  ///
		  `update' 
		


reg `party' assettreat `controls' [pw=vote_wgt]  if left_s3~=.,  robust

outreg2 using log/TableB2 , nocons keep(assettreat)  bdec(3) noaster label excel ///
		ctitle(`party', Reweighted)  ///
		  `update' 

xi: ivreg2 `party' (asset_comp= assettreat) `controls'  if left_s3~=.,  robust

outreg2 using log/TableB2 , nocons keep(asset_comp)  bdec(3) noaster label excel ///
		ctitle(`party', TOT)  ///
		 `update' 
}


********************************************************************************
* Table B3 : Treatment Effect on Party Vote in 2015: Multinomial Logit
********************************************************************************

set more off
use replicationdata.dta, clear
mlogit party_s3 assettreat left_2013 right_2013 age age2 willingrisk1to10 tradestock6all if left_s3~=., robust /*rrr*/
outreg2 using log/TableB3 , nocons keep(assettreat)  bdec(3) noaster  label excel replace



********************************************************************************
* Table B4: Treatment Effect on Ordered Vote Choice in 2015
********************************************************************************

set more off
use replicationdata.dta, clear

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
/* omitted relid is Secular, omitted nafa is Center (both largest) */

local update="replace"
local depvar="coarseorder"   

*PANEL A: ENTIRE POPULATION

* OLOGIT
xi: ologit `depvar'_s3  assettreat right_2013 left_2013 `dem_controls' i.block13, or  r
outreg2 using log/TableB4, bdec(3) eform  noaster label excel ctitle(OLOGIT, ) addstat(Pseudo R2, e(r2_p)) nocons ///
	keep(assettreat) ///
	`update'

	local update="append"

* OLOGIT Re-weighted   
xi: ologit `depvar'_s3  assettreat right_2013 left_2013 `dem_controls' i.block13 [pw=vote_wgt] , or  /*cluster(vote2013)*/ r 
outreg2 using log/TableB4, bdec(3) eform  noaster label excel ctitle(OLOGIT, ReWeighted) addstat(Pseudo R2, e(r2_p))  nocons ///
	keep(assettreat ) ///
	`update'

* OLS: ITT
areg `depvar'_s3  assettreat right_2013 left_2013 `dem_controls',  absorb (block13) r
outreg2 using log/TableB4 ,bdec(3) noaster label excel ctitle(OLS, ) nocons ///
	keep(assettreat ) ///
	`update'

* OLS: Re-weighted to represent jewish vote share in 2013   
areg `depvar'_s3  assettreat right_2013 left_2013 `dem_controls' [pw=vote_wgt],  absorb (block13) /*cluster(vote2013)*/ r 
outreg2 using log/TableB4 ,bdec(3) noaster label excel ctitle(OLS, ReWeighted) nocons ///
	keep(assettreat ) ///
	`update'
	   
		   
* IV-TOT	
xi: ivreg2 `depvar'_s3    (asset_comp=assettreat) i.block13 right_2013 left_2013 `dem_controls', r 
outreg2 using log/TableB4 ,bdec(3) noaster label excel ctitle(IV, TOT) nocons addstat(F(excluded instruments), `e(widstat)') ///
	keep(asset_comp ) ///
	`update'


*PANEL B: INEXPERIENCED 

local p=0
* OLOGIT
xi: ologit `depvar'_s3  assettreat right_2013 left_2013 `dem_controls' i.block13 if tradestock6all==`p', or  r
outreg2 using log/TableB4, bdec(3) eform  noaster label excel ctitle(OLOGIT, ,Inexperienced) addstat(Pseudo R2, e(r2_p)) nocons ///
	keep(assettreat) ///
	`update'


* OLOGIT Re-weighted   
xi: ologit `depvar'_s3  assettreat right_2013 left_2013 `dem_controls' i.block13 if tradestock6all==`p' [pw=vote_wgt] , or  /*cluster(vote2013)*/ r 
outreg2 using log/TableB4, bdec(3) eform  noaster label excel ctitle(OLOGIT, ReWeighted,Inexperienced) addstat(Pseudo R2, e(r2_p))  nocons ///
	keep(assettreat ) ///
	`update'

* OLS: ITT
areg `depvar'_s3  assettreat right_2013 left_2013 `dem_controls' if tradestock6all==`p',  absorb (block13) r
outreg2 using log/TableB4 ,bdec(3) noaster label excel ctitle(OLS, ,Inexperienced) nocons ///
	keep(assettreat ) ///
	`update'

* OLS: Re-weighted to represent jewish vote share in 2013   
areg `depvar'_s3  assettreat right_2013 left_2013 `dem_controls' [pw=vote_wgt] if tradestock6all==`p',  absorb (block13) /*cluster(vote2013)*/ r 
outreg2 using log/TableB4 ,bdec(3) noaster label excel ctitle(OLS, ReWeighted,Inexperienced) nocons ///
	keep(assettreat ) ///
	`update'
	   
	   
* IV-TOT	
xi: ivreg2 `depvar'_s3    (asset_comp=assettreat)  i.block13 right_2013 left_2013 `dem_controls' if tradestock6all==`p', r 
outreg2 using log/TableB4 ,bdec(3) noaster label excel ctitle(IV, TOT,Inexperienced) nocons addstat(F(excluded instruments), `e(widstat)') ///
	keep(asset_comp ) ///
	`update'


	
	
	
********************************************************************************
* Table B5: Difference-in-Difference Effects on Ordered Vote Choice in 2015
********************************************************************************


set more off
use replicationdata.dta, clear

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb newsesdum1-newsesdum7 willingrisk1to10 patient plitscore " 
* changed i.newses to faminc

gen vote15_observed=(left_s3<.)
keep uid assettreat asset_comp coarseorder_2013 coarseorder_s3 left_2013 left_s3 right_2013 right_s3 p_index_s1 p_index_s3 ///
	tradestock6all vote15_observed vote_wgt `dem_controls' block13 vote2013
	

foreach var in left right coarseorder {
rename `var'_s3 `var'2015
rename `var'_2013 `var'2013
}

rename p_index_s1 p_index2013 // not really, just for checking...
rename p_index_s3 p_index2015

reshape long left right coarseorder p_index, i(uid) j(year)
xtset uid year

gen y15=(year==2015)
label var y15 "2015"
gen treat_2015=assettreat*y15
label var treat_2015 "Asset Treatment x 2015"
gen comp_2015=asset_comp*y15

keep if vote15_observed // only keep observed vote in 2015. 
	* this means the intercept and the assettreat estimates do not use the attritted. 
	* since we have a bit more imbalance in the nonattritted, the assetreat effect is slightly larger 
	* and the interaction slightly smaller. 


* main table: DD coarseorder
****************************	
local update="replace"

foreach depvar in coarseorder {

* OLS, no FE
	reg `depvar' y15 assettreat treat_2015, cluster(uid)
	outreg2 using log/TableB5 ,noaster ///
		keep(y15 assettreat treat_2015) nocons addtext(Individual FE, NO) ///
		bdec(3) label excel ctitle(OLS)  ///
	   `update' 

local update="append"
 
* OLS, dem controls and strata FE
	reghdfe `depvar' y15 assettreat treat_2015 `dem_controls', absorb(block13) cluster(uid)
	outreg2 using log/TableB5 ,noaster ///
		keep(y15 assettreat treat_2015) nocons addtext(Individual FE, NO) ///
		bdec(3) label excel ctitle(OLS, controls)  ///
	   `update' 
 
  
* Individual FE (-> drop assettreat)
	reghdfe `depvar' y15 assettreat treat_2015, absorb(uid) cluster(uid)
	outreg2 using log/TableB5 ,noaster ///
		keep(y15 assettreat treat_2015) nocons addtext(Individual FE, YES) ///
		bdec(3) label excel ctitle(FE)  ///
	   `update' 

* Individual FE reweighted
	reghdfe `depvar' y15 assettreat treat_2015 [pw=vote_wgt], absorb(uid) cluster(uid) 
	outreg2 using log/TableB5 ,noaster ///
		keep(y15 assettreat treat_2015) nocons addtext(Individual FE, YES) ///
		bdec(3) label excel ctitle(reweighted)  ///
	   `update' 
   
* TOT
	reghdfe `depvar' y15 (comp_2015 = treat_2015) , absorb(uid) cluster(uid) est(2sls)
	outreg2 using log/TableB5 ,noaster ///
		keep(y15 comp_2015) nocons addtext(Individual FE, YES) ///
		bdec(3) label excel ctitle(TOT) ///
		sortvar(treat_2015 comp_2015 assettreat y15  ) addstat(F(excluded instruments), `e(widstat)') ///
	   `update' 
}



********************************************************************************
* Table B6: Financial Experience and Vote Choice, 2015
********************************************************************************

*OLS, one table, left and right 

set more off
use replicationdata.dta, clear

** Note in this regression we omit strata as we stratified explicitly on past trading experience (tradestock6all).
 
gen asset_inexp = assettreat ==1 & tradestock6all==0
gen asset_incomp = asset_comp ==1 & tradestock6all==0
 label var asset_inexp "Asset Treat x Inexperienced"
 label var asset_incomp "Asset Treat x Inexperienced"
local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses patient willingrisk1to10 plitscore " 
/* omitted relid is Secular, omitted nafa is Center (both largest) */

local update="replace"


foreach depvar in left right coarseorder   { 

  
* control for demographics 
reg `depvar'_s3  assettreat asset_inexp right_2013 left_2013 `dem_controls',  r
outreg2 using log/TableB6 ,bdec(3)  noaster  label excel ctitle(`depvar', Controls) nocons ///
	keep(assettreat  asset_inexp tradestock6all ) ///
	`update'
local update="append"

* Re-weighted to represent jewish vote share in 2013   
reg `depvar'_s3  assettreat asset_inexp right_2013 left_2013 `dem_controls' [pw=vote_wgt],  /*cluster(vote2013)*/ r 
outreg2 using log/TableB6 ,bdec(3)  noaster  label excel ctitle(`depvar', ReWeighted) nocons ///
	keep(assettreat  asset_inexp tradestock6all ) ///
	`update'
	   
		   
* IV-TOT	
xi: ivreg2 `depvar'_s3    (asset_comp asset_incomp=assettreat asset_inexp) right_2013 left_2013 `dem_controls', r
outreg2 using log/TableB6 ,bdec(3)  noaster  label excel ctitle(`depvar', TOT) nocons  addstat(F(excluded instruments), `e(widstat)') ///
	keep(asset_comp asset_incomp  asset_incomp tradestock6all) ///
	sortvar(tradestock6all assettreat asset_inexp asset_comp asset_incomp) ///
	`update'
	   
}





********************************************************************************
* Table B7: Are Treatment Effects Driven by The Voters of a Specific Party? 
********************************************************************************
set more off
use replicationdata.dta, clear

capture drop newpartyorder
**** Note the order is from right to left in our original coding with dnv / refuse in the middle.
* We reorder left to right, with dnv/ refuse at the end
* Note that none of our participants voted for Arab parties 13-15 in 2013
recode partyorder (12 =1)(11 = 2)(10=3)(9=4)(8=10)(5=5)(2=6)(3=7)(4=8)(1=9)(6=10)(7=11), gen(newpartyorder) 
* partyorder=	1 is habayit hayehudi
*  partyorder=	2	shas
*  partyorder=	3	 yahadut hatora
*  partyorder=	4	likud beitenu
*  partyorder=	5	kadima
*  partyorder=	6	 other
*  partyorder=	7	 didn't vote
*  partyorder=	8	refuse
*  partyorder=	9	yesh atid
*  partyorder=	10	hatnua
*  partyorder=	11	 labor
*  partyorder=	12	 meretz
*  partyorder=	13	 hadash
*  partyorder=	14	 balad
*  partyorder=	15	 raam taal

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
/* omitted relid is Secular, omitted nafa is Center (both largest) */

local update="replace"

forvalues party = 1(1)11 {
areg coarseorder_s3 assettreat `dem_controls' left_2013 right_2013 if newpartyorder~= `party', absorb(block13) r
outreg2 using log\TableB7 ,bdec(3) noaster label excel ctitle(`party') nocons ///
	keep(assettreat) ///
	`update'

	local update= "append"
	}
	


********************************************************************************
* Table B8: Treatment Effects by Religiosity, Gender, Age & Education
********************************************************************************
set more off
use replicationdata.dta, clear

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
/* omitted relid is Secular, omitted nafa is Center (both largest) */

local update="replace"


gen e_index_s3 = e_index_jul15 

gen young = age<=37
gen old = age>37
gen lesseduc = yearsedu<=13.5
gen moreeduc = yearsedu>13.5
gen binnedrel = r_ultra==1 | r_rel==1
gen binnedsec = r_sec==1 | r_trad==1

gen female = male==0


 recode newedu (0 1 2 = 1) (3 4 =0), gen(collegeminus)
recode newedu (3 4 = 1) (0 1 2 =0), gen(collegeplus) 

local update="replace"


** Descriptives
capture log close
log using log\TableB8descriptives.smcl, replace
foreach subset in binnedrel binnedsec  female  male  old young collegeplus collegeminus  {
su coarseorder_s3 p_index_s3 e_index_jul15 if `subset'==1
}

log close

foreach subset in binnedrel binnedsec   female male  old young  collegeplus collegeminus {

foreach depvar in coarseorder p_index e_index { 

  
areg `depvar'_s3  assettreat right_2013 left_2013 `dem_controls' if `subset'==1,  absorb (block13) r
outreg2 using log\TableB8 ,bdec(3) noaster label excel ctitle(`subset',`depvar') nocons ///
	keep(assettreat) ///
	`update'
local update="append"
}
}



********************************************************************************
* Table B9: Treatment Effects by Region
********************************************************************************
set more off
use replicationdata.dta, clear

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
/* omitted relid is Secular, omitted nafa is Center (both largest) */

local update="replace"


gen e_index_s3 = e_index_jul15 

local update="replace"


** Descriptives
capture log close
log using log\TableB9descriptives.smcl, replace
foreach subset in g_haifa g_north g_telaviv g_center  g_jerusalem g_wb g_south  {
su coarseorder_s3 p_index_s3 e_index_jul15 if `subset'==1
}
log close

foreach subset in g_haifa g_north g_telaviv g_center  g_jerusalem g_wb g_south {

foreach depvar in coarseorder p_index e_index { 

  
areg `depvar'_s3  assettreat right_2013 left_2013 `dem_controls' if `subset'==1,  absorb (block13) r
outreg2 using log\TableB9 ,bdec(3) noaster label excel ctitle(`subset',`depvar') nocons ///
	keep(assettreat) ///
	`update'
local update="append"
}
}



********************************************************************************
* Table B10: Treatment Effects on Knowledge of Political Platforms and Facts, April 2015
********************************************************************************
set more off
use replicationdata.dta, clear

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
local controls="i.block13 right_2013 left_2013 `dem_controls'"

local update="replace"

foreach var in BBdefence BBallowance BBtaxes BBvat BBsettle ///
	 {
		capture drop c_`var'
		gen c_`var'=0 
		label var c_`var' "correct `var'"
}	 


replace c_BBdefence =(BBdefence==3) 
replace c_BBallowance =(BBallowance==3 | BBallowance==2) 
replace c_BBtaxes  = (BBtaxes==1) 
replace c_BBvat = (BBvat==1 | BBvat==2) 
replace c_BBsettle = (BBsettle==1 | BBsettle==2) 
 
# delimit ; 
egen pol_info_a_score_tot= rowtotal(c_BBinvite c_BBcongress c_BBbar_ilan c_BBpre_election 
c_BBdefence c_BBallowance c_BBtaxes c_BBvat c_BBsettle c_HGpalstate c_HGrent c_HGminwage c_HGsettle c_threshold 
c_mini_for c_mini_fin c_mini_def c_mini_soc );
	
gen pol_info_a_score=pol_info_a_score_tot/18;	


label var pol_info_a_score "political info score augmented, info survey" ;

egen pol_plat_score_a_tot= rowtotal(c_BBinvite c_BBcongress c_BBbar_ilan c_BBpre_election  
c_BBdefence c_BBallowance c_BBtaxes c_BBvat c_BBsettle 
	c_HGpalstate c_HGrent c_HGminwage c_HGsettle ) ;

	gen pol_plat_a_score = pol_plat_score_a_tot/13;
	
label var pol_plat_a_score "political platform score augmented, info survey";

egen pol_plat_score_tot =  rowtotal(c_BBinvite c_BBcongress c_BBbar_ilan c_BBpre_election 
	c_HGpalstate c_HGrent c_HGminwage c_HGsettle );
	
gen pol_plat_score = pol_plat_score_tot / 	8;
label var pol_plat_a_score "political platform score , info survey";

# delimit cr


foreach var in c_BBdefence c_BBallowance c_BBtaxes c_BBvat c_BBsettle pol_info_a_score pol_plat_a_score pol_plat_score ///
	 {
	 replace `var' = . if pol_info_score==.
	 }

su econ_info_score c_unemp c_inflation c_mkt_updown c_mkt_up_percent  c_housing  pol_info_score pol_plat_score c_BBinvite c_BBcongress c_BBbar_ilan c_BBpre_election c_HGpalstate c_HGrent c_HGminwage c_HGsettle c_threshold c_mini_for c_mini_fin c_mini_def c_mini_soc c_BBdefence c_BBallowance c_BBtaxes c_BBvat c_BBsettle pol_info_a_score pol_plat_a_score 

foreach depvar in econ_info_score c_unemp c_inflation c_mkt_updown c_mkt_up_percent  c_housing  pol_info_score pol_plat_score c_BBinvite c_BBcongress c_BBbar_ilan c_BBpre_election c_HGpalstate c_HGrent c_HGminwage c_HGsettle c_threshold c_mini_for c_mini_fin c_mini_def c_mini_soc c_BBdefence c_BBallowance c_BBtaxes c_BBvat c_BBsettle pol_info_a_score pol_plat_a_score  {
  
	reg `depvar'  assettreat `controls', r
	outreg2 using log\TableB10 , nocons keep(assettreat)  bdec(3)  noaster   label excel  ///
		ctitle(`depvar', All) ///
		 sideway   `update' 
		
		local update="append"

	reg `depvar' assettreat `controls' if tradestock6all==0, r
	outreg2 using log\TableB10 , nocons keep(assettreat)  bdec(3) noaster  label excel ///
		ctitle(`depvar', Did Not Trade) ///
		 sideway   `update' 
}

********************************************************************************
* Table B11: Respondents Predict Greater Peace Benefits for Israel's Economy than for Its Security
********************************************************************************

set more off
use replicationdata.dta, clear
	
foreach depvar in rtwostisreconomicaf_s3 rtwostisrsecurityaf_s3 rtwostperseconomicaf_s3 rtwostperssafetyaf_s3   {
tab `depvar'
}

foreach wave in  s3 {
* national 
gen ecsecn_`wave'=1 if rtwostisreconomicaf_`wave'>rtwostisrsecurityaf_`wave' & rtwostisreconomicaf_`wave'<. & rtwostisrsecurityaf_`wave'<.
replace ecsecn_`wave'=0 if rtwostisreconomicaf_`wave'==rtwostisrsecurityaf_`wave' & rtwostisreconomicaf_`wave'<. & rtwostisrsecurityaf_`wave'<.
replace ecsecn_`wave'=-1 if rtwostisreconomicaf_`wave'<rtwostisrsecurityaf_`wave' & rtwostisreconomicaf_`wave'<. & rtwostisrsecurityaf_`wave'<.
label var ecsecn_`wave' "pdeal better for economy than security, `wave'"
*personal
gen ecsecp_`wave'=1 if rtwostperseconomicaf_`wave'>rtwostperssafetyaf_`wave' & rtwostperseconomicaf_`wave'<. & rtwostperssafetyaf_`wave'<.
replace ecsecp_`wave'=0 if rtwostperseconomicaf_`wave'==rtwostperssafetyaf_`wave' & rtwostperseconomicaf_`wave'<. & rtwostperssafetyaf_`wave'<.
replace ecsecp_`wave'=-1 if rtwostperseconomicaf_`wave'<rtwostperssafetyaf_`wave' & rtwostperseconomicaf_`wave'<. & rtwostperssafetyaf_`wave'<.
label var ecsecp_`wave' "pdeal better for personal ec sit than personal safety, `wave'"

tab ecsecn_`wave' 
tab ecsecn_`wave' assettreat, col
areg ecsecn_`wave' assettreat, absorb(block13)

}

capture log close
log using log/TableB11, replace

*** This includes the code that generates the cells tabulated in Table B11

tab ecsecn_s3
	*by right/left vote in 2013:
	tab ecsecn_s3 if right_2013
	tab ecsecn_s3 if left_2013

	*by positive or negative 
	gen both_pos=rtwostisreconomicaf_s3>3 & rtwostisrsecurityaf_s3>3 & rtwostisreconomicaf_s3<. & rtwostisrsecurityaf_s3<.
	gen both_neg=rtwostisreconomicaf_s3<3 & rtwostisrsecurityaf_s3<3 
	tab ecsecn_s3 both_pos, col
	tab ecsecn_s3 both_neg, col

	log close

*stop

********************************************************************************
* Table B12: Descriptive Statistics and Balance, 2016 Follow-Up Sample
********************************************************************************

* same tests as before (pretreatment vars)
* overall very well balanced - only new imbalance is we now have more settlers in our treatment, which works against us. 
* Check this.

set more off
use replicationdata.dta, clear

local population="left_2016<."

mat balance=J(52,7,.)

local i=0
foreach var in right_2013 left_2013 p_index_s1 e_index_init tradestock6all male age ///
		postsecondary BA_student college_grad married r_sec  r_trad r_relig r_ultra ///
		g_jerusalem g_north g_haifa g_center g_telaviv g_south g_wb faminc willingrisk1to10 patient plitscore ///
		{

	sum `var' if `population' & assettreat==1
		mat balance[`i'*2+1,1]=round(r(mean) , 0.001)
		mat balance[`i'*2+2,1]=round(r(sd), 0.001)

	sum `var' if `population' & assettreat==0
		mat balance[`i'*2+1,2]=round(r(mean) , 0.001)
		mat balance[`i'*2+2,2]=round(r(sd), 0.001)

	reg `var' assettreat if `population', r
		mat balance[`i'*2+1,3]=round(_b[assettreat], 0.001)
		mat balance[`i'*2+2,3]=round(_se[assettreat], 0.001)
		test assettreat
		mat balance[`i'*2+1,4]=round(r(p), 0.0001)

	areg `var' assettreat if `population', absorb(block13) r
		mat balance[`i'*2+1,5]=round(_b[assettreat], 0.001)
		mat balance[`i'*2+2,5]=round(_se[assettreat], 0.001)
		test assettreat
		mat balance[`i'*2+1,6]=round(r(p), 0.0001)
		mat balance[`i'*2+1,7]=e(N)
		
	local ++i		
}


mat colnames balance=Mean_assettreat Mean_control OLS p FE p Obs
mat rownames balance=right_2013 x left_2013 x p_index_s1 x e_index_init x tradestock6all x male x age x ///
		postsecondary x BA_student x college_grad x married x r_sec x r_trad x r_relig x r_ultra x ///
		g_jerusalem x g_north x g_haifa x g_center x g_telaviv x g_south x g_wb x faminc x willingrisk1to10 x patient x plitscore x

capture log close
log using log/TableB12, replace

*** This includes the code that generates the cells tabulated in Table B12

mat li balance

log close





********************************************************************************
* Table B13: Long-Term Effects on Intended Vote and Support for Peace Concessions, 2016 Follow-Up Sample
********************************************************************************
*OLS and IV, all regressions include full set of strata and demogs

set more off
use replicationdata.dta, clear

label var left_s3 "Voted Left '15"
label var right_s3 "Voted Right '15"

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
/* omitted relid is Secular, omitted nafa is Center (both largest) */

local update="replace"

foreach depvar in left right { 
  
* OLS  
areg `depvar'_2016  assettreat right_2013 left_2013 `dem_controls',  absorb (block13) r
outreg2 using log/TableB13 ,bdec(3) noaster label excel ctitle(`depvar', ITT) nocons ///
	keep(assettreat ) ///
	`update'

local update="append"

* IV-TOT	
xi: ivreg2 `depvar'_2016    (asset_comp=assettreat) i.block13 right_2013 left_2013  `dem_controls', r
outreg2 using log/TableB13 ,bdec(3) noaster label excel ctitle(`depvar', TOT) nocons  addstat(F(excluded instruments), `e(widstat)')  ///
	keep(asset_comp ) ///
	`update'

	
* Control for vote in 2015 (not entirely kosher since vote2015 is endogenous to treatment)

*OLS
areg `depvar'_2016  assettreat right_2013 left_2013 right_s3 left_s3 `dem_controls',  absorb (block13) r
outreg2 using log/TableB13 ,bdec(3) noaster label excel ctitle(`depvar', ITT) nocons ///
	keep(assettreat  right_s3 left_s3) ///
	`update'


* IV-TOT - controlling for vote in 2015 	
xi: ivreg2 `depvar'_2016    (asset_comp=assettreat) i.block13 right_2013 left_2013 right_s3 left_s3 `dem_controls', r
outreg2 using log/TableB13 ,bdec(3) noaster label excel ctitle(`depvar', TOT) nocons addstat(F(excluded instruments), `e(widstat)') ///
	keep(asset_comp  right_s3 left_s3) ///
	sortvar(assettreat asset_comp  right_s3 left_s3) ///
	`update'
}


foreach depvar in p_index { 
  
* OLS  
areg `depvar'_2016  assettreat right_2013 left_2013 `dem_controls',  absorb (block13) r
outreg2 using log/TableB13 ,bdec(3) noaster label excel ctitle(`depvar', ITT) nocons ///
	keep(assettreat) ///
	`update'

local update="append"

* IV-TOT	
xi: ivreg2 `depvar'_2016    (asset_comp=assettreat) i.block13 right_2013 left_2013 `dem_controls', r
outreg2 using log/TableB13 ,bdec(3) noaster label excel ctitle(`depvar', TOT) nocons  addstat(F(excluded instruments), `e(widstat)') ///
	keep(asset_comp ) ///
	`update'

	
* Control for vote in 2015 (not entirely kosher since vote2015 is endogenous to treatment)

*OLS
areg `depvar'_2016  assettreat right_2013 left_2013  p_index_s3 `dem_controls',  absorb (block13) r
outreg2 using log/TableB13 ,bdec(3) noaster label excel ctitle(`depvar', ITT) nocons ///
	keep(assettreat right_s3 left_s3 p_index_s3) ///
	`update'


* IV-TOT - controlling for vote in 2015 	
xi: ivreg2 `depvar'_2016    (asset_comp=assettreat) i.block13 right_2013 left_2013  p_index_s3 `dem_controls', r
outreg2 using log/TableB13 ,bdec(3) noaster label excel ctitle(`depvar', TOT) nocons addstat(F(excluded instruments), `e(widstat)') ///
	keep(asset_comp  p_index_s3) ///
	sortvar(assettreat asset_comp ) ///
	`update'
}




********************************************************************************
* Table B14: Long-Term Effects on Other Outcomes, 2016 Follow-Up Sample
********************************************************************************'

set more off
use replicationdata.dta, clear
*** Create Index for two state learning qn. First reverse scale - higher is improve more.
foreach var in twostisrsec_2016 twostisrecon_2016 twostpersec_2016 twostpersecon_2016 {
capture drop if `var'==0
capture drop r`var'
gen r`var'= 6-`var'
}

foreach var in blamepales_2016 integratewest_2016 {
capture drop if `var'==0
capture drop r`var'
gen r`var'= 5-`var'
}


foreach var in arabhighschool_2016 arabneighborhoods_2016 arabjointbus_2016 arabmanagers_2016 arabjointcoalition_2016  {
capture drop if `var'==0
}


* generate standardized vars (using control mean and sd)
foreach var in  ///
		rtwostisrsec_2016 rtwostisrsec_2016 rtwostisrecon_2016 rtwostpersec_2016 rtwostpersecon_2016  arabhighschool_2016 arabneighborhoods_2016 arabjointbus_2016 arabmanagers_2016 arabjointcoalition_2016 blamepales_2016 integratewest_2016	{
	capture drop m_`var' sd_`var' std_`var'
	sum `var' if assettreat==0  
	gen m_`var'=r(mean) 	// mean in control
	gen sd_`var'=r(sd) 	// sd in control
	gen std_`var'=(`var'-m_`var')/sd_`var'	//standardized var 
}	



*generate indices	
egen twost_isr_index_2016 = rowmean(std_rtwostisrsec_2016 std_rtwostisrecon_2016)
egen twost_per_index_2016 = rowmean(std_rtwostpersec_2016 std_rtwostpersecon_2016)

egen s_index_2016 = rowmean(std_arabneighborhoods_2016 std_arabhighschool_2016)

egen b_index_2016 = rowmean(std_arabjointbus_2016 std_arabmanagers_2016)

gen mainissueecon_2016 = mainissue_2016<3
replace mainissueecon_2016=. if mainissue_2016==.
gen mainissuepolsec_2016 = mainissue_2016>3 
replace mainissuepolsec_2016= . if mainissue_2016==.


local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 

local update="replace"


foreach depvar in p_index_2016 s_index_2016 b_index_2016  mainissueecon_2016 mainissuepolsec_2016 {
areg `depvar' assettreat right_2013 left_2013 `dem_controls',  absorb (block13) r
outreg2 using log\TableB14 , nocons keep(assettreat)  bdec(3) noaster label excel ///
	ctitle(`depvar', All) `update' sideway  nor2 

local update="append"

}

* specific outcomes (oprobits - ITT only. OLS/IV-TOT results qualitatively similar)
foreach depvar in pdealtwostate_2016 pdeal1967_2016 pdealsplitjerus_2016 pdealpalrefcomp_2016 ///
		 arabneighborhoods_2016 arabhighschool_2016 arabjointbus_2016 arabmanagers_2016 arabjointcoalition_2016 ///
		blamepales_2016 integratewest_2016 ///
		rtwostisrsec_2016 rtwostisrsec_2016 rtwostisrecon_2016 rtwostpersec_2016 rtwostpersecon_2016 ///
		nonegisrsec nonegisrecon nonegpersec nonegperecon {  

*OPROBIT - ITT 
xi: oprobit `depvar' assettreat right_2013 left_2013 `dem_controls' i.block13,  r
outreg2 using log\TableB14 , nocons keep(assettreat)  bdec(3) noaster label excel ///
	ctitle(`depvar', All) /*addstat(Pseudo R-squared, `e(r2_p)') */ `update' sideway  

	}

set more off
capture log close
log using log\TableB14descriptives.log, replace
*descriptives
su p_index_2016 pdealtwostate_2016 pdeal1967_2016 pdealsplitjerus_2016 pdealpalrefcomp_2016 ///
        s_index_2016 arabneighborhoods_2016 arabhighschool_2016  /// 
		b_index_2016  arabjointbus_2016 arabmanagers_2016 /// 
		   arabjointcoalition_2016 ///
		blamepales_2016 integratewest_2016 ///
		mainissueecon_2016 mainissuepolsec_2016  ///
		rtwostisrecon_2016 rtwostisrsec_2016 rtwostpersecon_2016 rtwostpersec_2016  ///
		nonegisrecon nonegisrsec  nonegperecon nonegpersec 
		
		log close





********************************************************************************
* Table B15: Election Polls and Asset Price Performance
********************************************************************************
clear
set more off
use "TableB15.dta", clear 

encode ticker, gen(tickerid)
xtset tickerid date

gen isrstock = ticker=="TA25" | ticker=="BEZQ" | ticker=="LUMI"
gen palstock = ticker=="BOP" | ticker=="PLE" | ticker=="PALTEL"

gen weeker = week(date)

gen likud_isrstock = pcent_seats_likud * isrstock
gen likud_palstock = pcent_seats_likud * palstock
gen zu_isrstock = pcent_seats_zu * isrstock
gen zu_palstock = pcent_seats_zu * palstock

gen date2 =date^2

gen right_isrstock = pcent_seats_right * isrstock
gen right_palstock = pcent_seats_right * palstock
gen left_palstock = pcent_seats_left * palstock
gen left_isrstock = pcent_seats_left * isrstock

label var pcent_seats_right "% Seats Predicted for the Right on Day"
label var pcent_seats_left "% Seats Predicted for the Left on Day"

label var right_isrstock "% Seats Right x Israeli Stock"
label var right_palstock "% Seats Right x Palestinian Stock"
label var left_isrstock "% Seats Left x Israeli Stock"
label var left_palstock "% Seats Left x Palestinian Stock"

label var pcent_seats_likud "% Seats Predicted for the Likud"
label var pcent_seats_zu "% Seats Predicted for the Zionist Union"

label var likud_isrstock "% Seats Likud x Israeli Stock"
label var zu_isrstock "% Seats Zionist Union x Israeli Stock"

label var likud_palstock "% Seats Likud x Palestinian Stock"
label var zu_palstock "% Seats Zionist Union x Palestinian Stock"


reg lastprice pcent_seats_right pcent_seats_left right_isrstock right_palstock left_isrstock left_palstock i.tickerid , r cluster(tickerid)
outreg2 using "log\TableB15", keep (pcent_seats_right pcent_seats_left right_isrstock right_palstock left_isrstock left_palstock) noaster bdec(3) label excel ///
		ctitle(FE) nocons replace
		
reg lastprice pcent_seats_right pcent_seats_left right_isrstock right_palstock left_isrstock left_palstock i.tickerid date date2, r cluster(tickerid)
outreg2 using "log\TableB15", keep (pcent_seats_right pcent_seats_left right_isrstock right_palstock left_isrstock left_palstock) noaster bdec(3) label excel ///
		ctitle(FE, date2) nocons append	
		
		reg lastprice pcent_seats_right pcent_seats_left right_isrstock right_palstock left_isrstock left_palstock i.tickerid date date2 i.weeker, r cluster(tickerid)
outreg2 using "log\TableB15", keep (pcent_seats_right pcent_seats_left right_isrstock right_palstock left_isrstock left_palstock) noaster  bdec(3) label excel ///
		ctitle(FE, date2, week FE) nocons append	
		
		reg lastprice pcent_seats_likud pcent_seats_zu likud_isrstock likud_palstock zu_isrstock zu_palstock i.tickerid , r cluster(tickerid)
outreg2 using "log\TableB15", keep (pcent_seats* right_isrstock right_palstock left_isrstock left_palstock likud* zu*) noaster bdec(3) label excel ///
		ctitle(FE) nocons append	
		
		reg lastprice pcent_seats_likud pcent_seats_zu likud_isrstock likud_palstock zu_isrstock zu_palstock i.tickerid date date2 i.weeker, r cluster(tickerid)
outreg2 using "log\TableB15", keep (pcent_seats* right_isrstock right_palstock left_isrstock left_palstock likud* zu*) noaster bdec(3) label excel ///
		ctitle(FE, date2, week FE) nocons append			


********************************************************************************
* Table B16: Engagement and Perceived Determinants of Asset Value among Compliers
********************************************************************************

set more off
use replicationdata.dta, clear


*******************************************************************************
** Panel A
local update="replace"
foreach depvar in eng_z ddtotime_wkfin_m4 facts_0_m4 tradetot_m4 active_bm4 bought_bm4 sold_bm4 {

areg `depvar' palstock cash high late pricechange_m4 male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient litscore left_2013 right_2013 if stat_instructions==1, absorb(block13) r
outreg2 using log\TableB16AB , bdec(3)  ctitle(OLS, `depvar') keep(palstock cash high late pricechange_m4) noaster label excel  `update' nocons  
local update="append"
}

*** Panel B


foreach depvar in facts_0_m4 assettype lastweek last3yrs nextweek {

areg `depvar' palstock cash high late pricechange_m4 male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient litscore left_2013 right_2013 if stat_instructions==1, absorb(block13) r
outreg2 using log\TableB16AB , bdec(3)  ctitle(OLS, `depvar') keep(palstock cash high late pricechange_m4) noaster label excel  `update' nocons  
local update="append"
}



****** Panel C
set more off
use replicationdata.dta, clear
local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 

local update="replace"
foreach depvar in detstmangrs_m4 detstworkrs_m4  detstmacro_m4 detstdompol_m4 detstinterstate_m4  {

areg `depvar' palstock cash high late pricechange_m16  `dem_controls' left_2013 right_2013 if stat_instructions==1, absorb(block13) r
outreg2 using log/TableB16C, bdec(3)  ctitle(OLS, `depvar') keep(palstock cash high late pricechange_m16) noaster label excel  `update' nocons  
local update="append"
}

capture log close
log using "log\TableB16descriptives.smcl", replace
su eng_z ddtotime_wkfin_m4 facts_0_m4 tradetot_m4 active_bm4 bought_bm4 sold_bm4   if stat_instructions==1
su facts_0_m4 assettype lastweek last3yrs nextweek if stat_instructions==1
su detstmangrs_m4 detstworkrs_m4 detstmacro_m4 detstdompol_m4 detstinterstate_m4 if stat_instructions==1
log close


********************************************************************************
* Table B17: Perceived Determinants of Asset Value and Political Attitudes among Compliers
********************************************************************************
set more off
use replicationdata.dta, clear

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 

local update="replace"
foreach depvar in coarseorder_s3 p_index_s3 e_index_f {

areg `depvar' detstworkrs_m4  detstmacro_m4 detstdompol_m4 detstinterstate_m4 `dem_controls' left_2013 right_2013 , absorb(block13) r
outreg2 using log/TableB17 , bdec(3)  ctitle(OLS, `depvar')  keep( detstworkrs_m4  detstmacro_m4 detstdompol_m4 detstinterstate_m4) noaster label excel  `update' nocons  
local update ="append"

}




********************************************************************************
* Table B18: Social and Business Attitudes towards Israeli Arabs
********************************************************************************

set more off
use replicationdata.dta, clear

local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
local controls="i.block13 right_2013 left_2013 `dem_controls'"

local update="replace"

foreach depvar of varlist s_index_s3 b_index_s3 {

reg `depvar' assettreat `controls', r
outreg2 using log/TableB18 , nocons keep(assettreat) noaster bdec(3) label excel ///
		ctitle(`depvar', All)  ///
		`update' 

local update="append"
}

foreach depvar of varlist  arabjointcoalition_s3 arabneighbourhood_s3 arabhighschool_s3 arabjointbusiness_s3 arabmanager_s3  {

	oprobit `depvar'  assettreat `controls', r
	outreg2 using log/TableB18 , nocons keep(assettreat) addstat(Pseudo R-squared, `e(r2_p)') noaster bdec(3) label excel ///
		ctitle(`depvar', All)  ///
		 `update' 
		 
	local update="append"
}
	
	capture log close
log using "log\TableB18descriptives.smcl", replace
	sum arabjointcoalition_s3 s_index_s3 arabneighbourhood_s3 arabhighschool_s3 b_index_s3  arabjointbusiness_s3 arabmanager_s3 

log close

********************************************************************************
* Table B19: Additional Questions from the post-Election Survey
********************************************************************************


set more off
use replicationdata.dta, clear
*** There was a technical glitch with the questions below which allowed inadmissible responses. Recode belonging questions so that 1 or 10 is belong most, 2 or 20 is belong second most and 3 is other.

foreach var of varlist belisraeli_s3-belimmigrant_s3 {
capture drop `var'r_s3
recode `var' (1 10 = 1) (2 20 = 2) (0 3/9 11/19 21/100 = 3), gen(rc`var')   
}
 
local dem_controls="male age age2 postsecondary BA_student college_grad married tradestock6all r_trad r_relig r_ultra g_jerusalem g_north g_haifa g_telaviv g_south g_wb i.newses willingrisk1to10 patient plitscore " 
local controls="i.block13 right_2013 left_2013 `dem_controls'"

local update="replace"

foreach depvar of varlist  rcbelisraeli_s3-rcbelimmigrant_s3 proudisraeli_s3-proudimmigrants_s3 preferisrael_s3 proudisrael_s3  support_settlements_s3 blamepales_s3 integratewest_s3 {

	oprobit `depvar'  assettreat `controls', r
	outreg2 using log/TableB19 , nocons keep(assettreat)  addstat(Pseudo R-squared, `e(r2_p)')  bdec(3) noaster label excel ///
		ctitle(`depvar', All)  ///
	 `update' 

	local update="append"
}


* descriptives
	capture log close
log using "log\TableB19descriptives.smcl", replace
sum  rcbelisraeli_s3-rcbelimmigrant_s3 proudisraeli_s3-proudimmigrants_s3 preferisrael_s3 proudisrael_s3 support_settlements_s3 blamepales_s3 integratewest_s3 
log close
